@@ -166,7 +166,7 @@ if len( args ) == 0:
                 print 'direct %s "HP Fax 3" "%s LPT HP Fax HPLIP" "MFG:HP;MDL:Fax 3;DES:HP Fax 3;"' % \
                     (uri.replace("hp:", "hpfax:"), model.replace('_', ' '))
 
-        elif mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_SOAP,):
+        elif mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_SOAP,) or mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_LEDMSOAP,):
             # HP Fax 2
             if bus == 'usb':
                 print 'direct %s "HP Fax 2" "%s USB %s HP Fax HPLIP" "MFG:HP;MDL:Fax 2;DES:HP Fax 2;"' % \
@@ -175,6 +175,15 @@ if len( args ) == 0:
             else: # par
                 print 'direct %s "HP Fax 2" "%s LPT HP Fax HPLIP" "MFG:HP;MDL:Fax 2;DES:HP Fax 2;"' % \
                     (uri.replace("hp:", "hpfax:"), model.replace('_', ' '))
+        elif mq.get('fax-type', FAX_TYPE_NONE) in (FAX_TYPE_LEDM,):
+            # HP Fax 4
+            if bus == 'usb':
+                print 'direct %s "HP Fax 4" "%s USB %s HP Fax HPLIP" "MFG:HP;MDL:Fax 4;DES:HP Fax 4;"' % \
+                    (uri.replace("hp:", "hpfax:"), model.replace('_', ' '), serial)
+
+            else: # par
+                print 'direct %s "HP Fax 4" "%s LPT HP Fax HPLIP" "MFG:HP;MDL:Fax 4;DES:HP Fax 4;"' % \
+                    (uri.replace("hp:", "hpfax:"), model.replace('_', ' '))
 
         else:
             # HP Fax
